Enumeration
HaslGs2HeaderChannelBinding
since: 0.3
Description [src]
This enum tells the header about channel bindings for this connection. See https://datatracker.ietf.org/doc/html/rfc5801#section-4 for more information.
Available since: 0.3
Members
-
HaslGs2HeaderChannelBindingClientNotSupported -
The client doesn’t support channel binding.
- Value:
0 - Available since: 0.3
- Value:
-
HaslGs2HeaderChannelBindingClientSupported -
The client supports channel binding and has specified a name.
- Value:
1 - Available since: 0.3
- Value:
-
HaslGs2HeaderChannelBindingClientSupportedServerUnknown -
The client supports channel binding, doesn’t know if the server does.
- Value:
2 - Available since: 0.3
- Value: